module GL_ARB_separate_shader_objects
  module Constants
    VERTEX_SHADER_BIT          = 0x00000001
    FRAGMENT_SHADER_BIT        = 0x00000002
    GEOMETRY_SHADER_BIT        = 0x00000004
    TESS_CONTROL_SHADER_BIT    = 0x00000008
    TESS_EVALUATION_SHADER_BIT = 0x00000010
    ALL_SHADER_BITS            = 0xFFFFFFFF
    PROGRAM_SEPARABLE          = 0x8258
    ACTIVE_PROGRAM             = 0x8259
    PROGRAM_PIPELINE_BINDING   = 0x825A
  end
  
  Functions = {
    def glUseProgramStages(pipeline, stages, program) end => [ :void, :GLuint, :GLbitfield, :GLuint ].freeze,
    def glActiveShaderProgram(pipeline, program) end => [ :void, :GLuint, :GLuint ].freeze,
    def glCreateShaderProgramv(type, count, strings) end => [ :GLuint, :GLenum, :GLsizei, :pointer ].freeze,
    def glBindProgramPipeline(pipeline) end => [ :void, :GLuint ].freeze,
    def glDeleteProgramPipelines(n, pipelines) end => [ :void, :GLsizei, :pointer ].freeze,
    def glGenProgramPipelines(n, pipelines) end => [ :void, :GLsizei, :pointer ].freeze,
    def glIsProgramPipeline(pipeline) end => [ :GLboolean, :GLuint ].freeze,
    def glGetProgramPipelineiv(pipeline, pname, params) end => [ :void, :GLuint, :GLenum, :pointer ].freeze,
    def glProgramParameteri(program, pname, value) end => [ :void, :GLuint, :GLenum, :GLint ].freeze,
    def glProgramUniform1i(program, location, v0) end => [ :void, :GLuint, :GLint, :GLint ].freeze,
    def glProgramUniform1iv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform1f(program, location, v0) end => [ :void, :GLuint, :GLint, :GLfloat ].freeze,
    def glProgramUniform1fv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform1d(program, location, v0) end => [ :void, :GLuint, :GLint, :GLdouble ].freeze,
    def glProgramUniform1dv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform1ui(program, location, v0) end => [ :void, :GLuint, :GLint, :GLuint ].freeze,
    def glProgramUniform1uiv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2i(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform2iv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2f(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform2fv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2d(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLdouble, :GLdouble ].freeze,
    def glProgramUniform2dv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2ui(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint ].freeze,
    def glProgramUniform2uiv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3i(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform3iv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3f(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform3fv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3d(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLdouble, :GLdouble, :GLdouble ].freeze,
    def glProgramUniform3dv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3ui(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint, :GLuint ].freeze,
    def glProgramUniform3uiv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4i(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform4iv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4f(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform4fv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4d(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLdouble, :GLdouble, :GLdouble, :GLdouble ].freeze,
    def glProgramUniform4dv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4ui(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint, :GLuint, :GLuint ].freeze,
    def glProgramUniform4uiv(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniformMatrix2fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2x3fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x2fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2x4fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x2fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x4fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x3fv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2x3dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x2dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2x4dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x2dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x4dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x3dv(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glValidateProgramPipeline(pipeline) end => [ :void, :GLuint ].freeze,
    def glGetProgramPipelineInfoLog(pipeline, bufSize, length, infoLog) end => [ :void, :GLuint, :GLsizei, :pointer, :string ].freeze,
  }.freeze
end