module GL_EXT_separate_shader_objects
  module Constants
    ACTIVE_PROGRAM_EXT           = 0x8B8D
    VERTEX_SHADER_BIT_EXT        = 0x00000001
    FRAGMENT_SHADER_BIT_EXT      = 0x00000002
    ALL_SHADER_BITS_EXT          = 0xFFFFFFFF
    PROGRAM_SEPARABLE_EXT        = 0x8258
    PROGRAM_PIPELINE_BINDING_EXT = 0x825A
  end
  
  Functions = {
    def glUseShaderProgramEXT(type, program) end => [ :void, :GLenum, :GLuint ].freeze,
    def glActiveProgramEXT(program) end => [ :void, :GLuint ].freeze,
    def glCreateShaderProgramEXT(type, string) end => [ :GLuint, :GLenum, :string ].freeze,
    def glActiveShaderProgramEXT(pipeline, program) end => [ :void, :GLuint, :GLuint ].freeze,
    def glBindProgramPipelineEXT(pipeline) end => [ :void, :GLuint ].freeze,
    def glCreateShaderProgramvEXT(type, count, strings) end => [ :GLuint, :GLenum, :GLsizei, :pointer ].freeze,
    def glDeleteProgramPipelinesEXT(n, pipelines) end => [ :void, :GLsizei, :pointer ].freeze,
    def glGenProgramPipelinesEXT(n, pipelines) end => [ :void, :GLsizei, :pointer ].freeze,
    def glGetProgramPipelineInfoLogEXT(pipeline, bufSize, length, infoLog) end => [ :void, :GLuint, :GLsizei, :pointer, :string ].freeze,
    def glGetProgramPipelineivEXT(pipeline, pname, params) end => [ :void, :GLuint, :GLenum, :pointer ].freeze,
    def glIsProgramPipelineEXT(pipeline) end => [ :GLboolean, :GLuint ].freeze,
    def glProgramParameteriEXT(program, pname, value) end => [ :void, :GLuint, :GLenum, :GLint ].freeze,
    def glProgramUniform1fEXT(program, location, v0) end => [ :void, :GLuint, :GLint, :GLfloat ].freeze,
    def glProgramUniform1fvEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform1iEXT(program, location, v0) end => [ :void, :GLuint, :GLint, :GLint ].freeze,
    def glProgramUniform1ivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2fEXT(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform2fvEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2iEXT(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform2ivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3fEXT(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform3fvEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3iEXT(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform3ivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4fEXT(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLfloat, :GLfloat, :GLfloat, :GLfloat ].freeze,
    def glProgramUniform4fvEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4iEXT(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLint, :GLint, :GLint, :GLint ].freeze,
    def glProgramUniform4ivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniformMatrix2fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glUseProgramStagesEXT(pipeline, stages, program) end => [ :void, :GLuint, :GLbitfield, :GLuint ].freeze,
    def glValidateProgramPipelineEXT(pipeline) end => [ :void, :GLuint ].freeze,
    def glProgramUniform1uiEXT(program, location, v0) end => [ :void, :GLuint, :GLint, :GLuint ].freeze,
    def glProgramUniform2uiEXT(program, location, v0, v1) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint ].freeze,
    def glProgramUniform3uiEXT(program, location, v0, v1, v2) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint, :GLuint ].freeze,
    def glProgramUniform4uiEXT(program, location, v0, v1, v2, v3) end => [ :void, :GLuint, :GLint, :GLuint, :GLuint, :GLuint, :GLuint ].freeze,
    def glProgramUniform1uivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform2uivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform3uivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniform4uivEXT(program, location, count, value) end => [ :void, :GLuint, :GLint, :GLsizei, :pointer ].freeze,
    def glProgramUniformMatrix2x3fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x2fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix2x4fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x2fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix3x4fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
    def glProgramUniformMatrix4x3fvEXT(program, location, count, transpose, value) end => [ :void, :GLuint, :GLint, :GLsizei, :GLboolean, :pointer ].freeze,
  }.freeze
end